.. _phononic-band_gaps:

phononic/band_gaps.py
=====================

**Description**


Acoustic band gaps in a strongly heterogeneous elastic body, detected using
homogenization techniques.

A reference periodic cell contains two domains: the stiff matrix :math:`Y_m`
and the soft (but heavy) inclusion :math:`Y_c`.


.. image:: /../doc/images/gallery/phononic-band_gaps-band_gaps.png
.. image:: /../doc/images/gallery/phononic-band_gaps.png


:download:`source code </../sfepy/examples/phononic/band_gaps.py>`

.. literalinclude:: /../sfepy/examples/phononic/band_gaps.py

